Core types, traits, and error handling for HyperInfer
This crate contains shared data structures, traits, and error definitions used across the entire HyperInfer monorepo.
Re-exports
pub use error::ConfigError;pub use error::DbError;pub use error::HyperInferError;pub use rate_limiting::RateLimiter;pub use rate_limiting::USAGE_REQUESTS_KEY_PREFIX;pub use rate_limiting::USAGE_TOKENS_KEY_PREFIX;pub use redis::PolicyUpdate;pub use telemetry_consumer::TelemetryConsumer;pub use traits::ApiKey;pub use traits::ConfigStore;pub use traits::Database;pub use traits::ModelAlias;pub use traits::Quota;pub use traits::Team;pub use traits::UsageLog;pub use traits::User;pub use types::ChatChunk;pub use types::ChatMessage;pub use types::ChatRequest;pub use types::ChatResponse;pub use types::Choice;pub use types::Config;pub use types::CreateDeploymentRequest;pub use types::Deployment;pub use types::MessageRole;pub use types::Provider;pub use types::RoutingConfig;pub use types::RoutingRule;pub use types::UpdateRoutingConfigRequest;pub use types::Usage;pub use types::UsageRecord;
Modules
- error
- Error handling for HyperInfer
- rate_
limiting - Rate limiting utilities for HyperInfer
- redis
- Redis utilities for HyperInfer
- telemetry_
consumer - Telemetry consumer for reading usage data from Redis Streams
- traits
- types
- Shared data types for HyperInfer