Telemetry consumer for reading usage data from Redis Streams
This consumer reads telemetry data pushed by hyperinfer-client from Redis Streams and can forward it to a database for persistence.
Telemetry consumer for reading usage data from Redis Streams
This consumer reads telemetry data pushed by hyperinfer-client from Redis Streams and can forward it to a database for persistence.